require File.dirname(__FILE__) + '/bootstrap.rb'

class BeckonClient < Sinatra::Base
  
  configure do
    set :root,  File.dirname(__FILE__)
    set :views, File.join(Sinatra::Application.root, 'views')
    set :haml,  {:format => :html5 }
  end
  
  get '/' do
    @configuration = Configuration.first(:active => true)
    
    haml :beckonclient
  end
  
  get '/configurations/?' do
    content_type :json
    Configuration.all.to_json
  end
  
  get '/configurations/:id' do
    @configuration = Configuration.first(:id => params[:id])
    
    unless @configuration.nil?
      content_type :json
      @configuration.to_json
    else
      halt 404
    end
  end
  
  get '/configurations/activate/:id' do
    @configuration = Configuration.first(:id => params[:id])
    
    unless @configuration.nil?
      content_type :json
      @configuration.activate
      @configuration.to_json
    else
      halt 404
    end
  end
  
  get '/configurations/update/:id' do
    @configuration = Configuration.first(:id => params[:id])
    
    unless @configuration.nil?
      content_type :json
      @configuration.update_remote
      @configuration.to_json
    else
      halt 404
    end
  end
  
  post '/configurations/?' do
    @content = JSON.parse(request.body.read)['configuration']
    
    unless @content.nil?
      @configuration = Configuration.new(@content)
      
      content_type :json
      if @configuration.save && @configuration.update_remote
        status 201
        @configuration.to_json
      else
        status 406
        {:errors => @configuration.errors}.to_json
      end
    else
      halt 406
    end
  end
  
  put '/configurations/:id' do
    @configuration = Configuration.first(:id => params[:id])
    
    unless @configuration.nil?
      @content = JSON.parse(request.body.read)['configuration']
      unless @content.nil?
        content_type :json
        if @configuration.update(@content)
          status 200
          @configuration.to_json
        else
          {:errors => @configuration.errors}.to_json
          status 406
        end
      else
        halt 406
      end
    else
      halt 404
    end
  end
  
  delete '/configurations/:id' do
    @configuration = Configuration.first(:id => params[:id])
    
    unless @configuration.nil?
      content_type :json
      @configuration.destroy
      @configuration.to_json
    else
      halt 404
    end
  end
  
  get '/*' do
    redirect '/'
  end
end