class Configuration
  include DataMapper::Resource
  
  property :id,           String,   :default => UUID.generate(:compact), :key => true
  property :title,        String,   :default => 'Untitled'
  property :url,          String
  property :api_key,      String
  property :api_secret,   String
  property :active,       Boolean,  :default => false
  property :created_at,   DateTime, :default => Time.now
  property :updated_at,   DateTime, :default => Time.now
  
  validates_presence_of :url, :api_key, :api_secret
  
  has n, :campaigns, :constraint => :destroy
  
  def campaign
    self.campaigns.first(:active => true)
  end
  
  def activate
    Configuration.all.each do |configuration|
      configuration.active = false
      configuration.save
    end
    self.active = true
    self.save
  end
  
  def update_remote
    begin
      campaigns_resource = RestClient::Resource.new(URI.join(self.url, 'campaigns').to_s, :user => self.api_key, :password => self.api_secret)
      presentations_resource = RestClient::Resource.new(URI.join(self.url, 'presentations').to_s, :user => self.api_key, :password => self.api_secret)
      slides_resource = RestClient::Resource.new(URI.join(self.url, 'slides').to_s, :user => self.api_key, :password => self.api_secret)
  
      campaigns_response = campaigns_resource.get(:content_type => 'json', :accept => 'json')
      presentations_response = presentations_resource.get(:content_type => 'json', :accept => 'json')
      slides_response = slides_resource.get(:content_type => 'json', :accept => 'json')
      
      if campaigns_response.code == 200 && presentations_response.code == 200 && slides_response.code == 200
        remote_campaigns = JSON.parse(campaigns_response.body)
        remote_presentations = JSON.parse(presentations_response.body)
        remote_slides = JSON.parse(slides_response.body)
        
        self.campaigns.destroy
        
        remote_campaigns.each do |campaign|
          campaign = campaign['campaign']
          sequence = campaign['sequence'].nil? ? nil : campaign['sequence'].join(',')
          
          self.campaigns.create({
            :id => campaign['id'],
            :title => campaign['title'],
            :description => campaign['description'],
            :stylesheet => campaign['stylesheet'],
            :sequence => sequence,
            :randomize => campaign['randomize'],
            :active => campaign['active'],
            :created_at => campaign['created_at'],
            :updated_at => campaign['updated_at']
          })
        end
        
        remote_presentations.each do |presentation|
          presentation = presentation['presentation']
          sequence = presentation['sequence'].nil? ? nil : presentation['sequence'].join(',')
          
          Presentation.create({
            :id => presentation['id'],
            :campaign_id => presentation['campaign_id'],
            :title => presentation['title'],
            :description => presentation['description'],
            :sequence => sequence,
            :duration => presentation['duration'],
            :transition => presentation['transition'],
            :randomize => presentation['randomize'],
            :created_at => presentation['created_at'],
            :updated_at => presentation['updated_at']
          })
        end
        
        remote_slides.each do |slide|
          slide = slide['slide']
          
          Slide.create({
            :id => slide['id'],
            :presentation_id => slide['presentation_id'],
            :title => slide['title'],
            :description => slide['description'],
            :markup => slide['markup'],
            :created_at => slide['created_at'],
            :updated_at => slide['updated_at']
          })
        end
        
        self.updated_at = Time.now
        self.save
        
        return true
      else
        return false
      end
    rescue Exception => e
      puts e
      return false
    end
    
    return true
  end
end